#!/bin/bash
#
### BEGIN INIT INFO
# Provides:          openafs-ramdisk
# Required-Start:    $local_fs
# Required-Stop:
# X-Start-Before:    openafs-client
# X-Stop-Before:     openafs-client
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Ramdisk base cache for openafs
# Description:       Ensures, openafs has a ramdisk at hand using a
#                    suitable filesystem (ext2)
### END INIT INFO
#
# -- Frank Burkhardt <burk@cbs.mpg.de>  Tue, 08 Jun 2010 10:21:26 +0200

PATH=/sbin:/bin:/usr/sbin:/usr/bin
NAME=openafs-ramdisk
DESC="RAM disk for openafs-client"

set -e
LANG=C

# Make sure, systemd takes over
. /lib/lsb/init-functions

if [ ! -x /usr/sbin/openafs-ramdisk ]; then
	# Package no longer installed
	exit 0
fi

case "$1" in
  start)
	echo -n "Starting $DESC: $NAME "
	/usr/sbin/openafs-ramdisk start
	echo "."
	;;
  stop)
	echo -n "Stopping $DESC: $NAME"
	/usr/sbin/openafs-ramdisk stop
	echo "."
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop}" >&2
	exit 1
	;;
esac

exit 0
